@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-23'; # DATE
+our $DATE = '2022-10-11'; # DATE
 our $DIST = 'Text-Table-HTML'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 sub _encode {
     state $load = do { require HTML::Entities };
@@ -25,9 +25,9 @@ sub table {
 
     push @table, "<table>\n";
 
-    if (defined $params{caption}) {
+    if (defined $params{title}) {
         require HTML::Entities;
-        push @table, "<caption>".HTML::Entities::encode_entities($params{caption})."</caption>\n";
+        push @table, "<caption>".HTML::Entities::encode_entities($params{title})."</caption>\n";
     }
 
     # then the data
@@ -41,17 +41,35 @@ sub table {
         } else {
             if ($i == 1) { push @table, "<tbody>\n" }
         }
-        push @table, "<tr>";
+
+        my $has_bottom_border = grep { ref $_ eq 'HASH' && $_->{bottom_border} } @$row;
+
+        push @table, "<tr".($has_bottom_border ? " class=has_bottom_border" : "").">";
         for my $cell (@$row) {
-            my $text    = ref $cell eq 'HASH' ? $cell->{text} : $cell;
+            my ($text, $encode_text) = @_;
+            if (ref $cell eq 'HASH') {
+                if (defined $cell->{raw_html}) {
+                    $text = $cell->{raw_html};
+                    $encode_text = 0;
+                } else {
+                    $text = $cell->{text};
+                    $encode_text = 1;
+                }
+            } else {
+                $text = $cell;
+                $encode_text = 1;
+            }
+            $text //= '';
             my $rowspan = int((ref $cell eq 'HASH' ? $cell->{rowspan} : undef) // 1);
             my $colspan = int((ref $cell eq 'HASH' ? $cell->{colspan} : undef) // 1);
+            my $align   = ref $cell eq 'HASH' ? $cell->{align} : undef;
             push @table,
                 ($in_header ? "<th" : "<td"),
                 ($rowspan > 1 ? " rowspan=$rowspan" : ""),
                 ($colspan > 1 ? " colspan=$colspan" : ""),
+                ($align       ? " align=\"$align\"" : ""),
                 ">",
-                _encode($text // ''),
+                $encode_text ? _encode($text) : $text,
                 $in_header ? "</th>" : "</td>";
 	}
         push @table, "</tr>\n";
@@ -98,7 +116,7 @@ Text::Table::HTML - Generate HTML table
 
 =head1 VERSION
 
-This document describes version 0.007 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2022-01-23.
+This document describes version 0.008 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2022-10-11.
 
 =head1 SYNOPSIS
 
@@ -148,13 +166,14 @@ The C<table> function understands these arguments, which are passed as a hash.
 
 Takes an array reference which should contain one or more rows of data, where
 each row is an array reference. And each array element is a string (cell
-content) or hashref (with key C<text> to contain the cell text, and optionally
+content) or hashref (with key C<text> to contain the cell text or C<raw_html> to
+contain the cell's raw HTML which won't be escaped further), and optionally
 attributes too like C<rowspan>, C<colspan>).
 
-=item * caption
+=item * title
 
 Optional. Str. If set, will add an HTML C<< <caption> >> element to set the
-provided table caption.
+table caption.
 
 =back
 
@@ -191,13 +210,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
